#' @title Simulate example data for [tar_stan_example_file()].
#' @export
#' @description An example dataset compatible with the model file
#'   from [tar_stan_example_file()].
#' @family examples
#' @return List, dataset compatible with the model file from
#'   [tar_stan_example_file()].
#' @format A list with the following elements:
#'   * `n`: integer, number of data points.
#'   * `x`: numeric, covariate vector.
#'   * `y`: numeric, response variable.
#'   * `true_beta`: numeric of length 1, value of the regression
#'     coefficient `beta` used in simulation.
#'   * `.join_data`: a list of simulated values to be appended
#'     to as a `.join_data` column in the output of
#'     targets generated by functions such as
#'     [tar_stan_mcmc_rep_summary()]. Contains the
#'     regression coefficient `beta` (numeric of length 1)
#'     and prior predictive data `y` (numeric vector).
#' @param n Integer of length 1, number of data points.
#' @examples
#' tar_stan_example_data()
tar_stan_example_data <- function(n = 10L) {
  beta <- stats::rnorm(n = 1, mean = 0, sd = 1)
  x <- seq(from = -1, to = 1, length.out = n)
  y <- stats::rnorm(n, x * beta, 1)
  list(
    n = n,
    x = x,
    y = y,
    true_beta = beta,
    .join_data = list(beta = beta, y_rep = y)
  )
}
